/*
    SPDX-FileCopyrightText: 2024 Jin Liu <m.liu.jin@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "hidecursor.h"

namespace KWin
{

KWIN_EFFECT_FACTORY(HideCursorEffect,
                    "metadata.json.stripped")

} // namespace KWin

#include "main.moc"
